"""
Script for NodeIntersectionPoint
"""

import NemAll_Python_Geometry as AllplanGeo

from NodeUtil import NodeBase, NodeFunctionUtil, NodePlaneUtil, NodeParameterTest


NodeBase.trace_node_name('NodeIntersectionPoint')


def create_node(init_data):
    """
    Create the node

    Args:
        init_data:  data for the node initialization
    """

    return NodeIntersectionPoint(init_data)


class NodeIntersectionPoint(NodeBase):
    """
    Definition of class NodeIntersectionPoint
    """

    def _create_output(self):
        """
        Create the intersection points
        """

        build_ele = self.build_ele

        self._set_init_node_output(build_ele.IntersectionPoints)

        if NodeParameterTest.test_empty_parameter(self, build_ele, "", ["Object1", "Object2"]):
            return


        #----------------- local function for the intersection calculation

        def calc_intersection_point(geo_object1, geo_object2):
            if build_ele.IntersectionPointAtElement.value:
                result, intersect_pnt = AllplanGeo.IntersectionCalculus(NodePlaneUtil.convert_to_plane(geo_object1),
                                                                        NodePlaneUtil.convert_to_plane(geo_object2),
                                                                        0.1,
                                                                        1000)

                if result:
                    return list(intersect_pnt) if len(intersect_pnt) > 1 else intersect_pnt[0]

                return None

            result, intersect_pnt = AllplanGeo.IntersectionCalculusEx(NodePlaneUtil.convert_to_plane(geo_object1),
                                                                      NodePlaneUtil.convert_to_plane(geo_object2),
                                                                      0.1,
                                                                      1000,
                                                                      False)

            if result:
                return list(intersect_pnt) if len(intersect_pnt) > 1 else intersect_pnt[0]

            self.warning = "Intersection not possible"

            return None

        build_ele.IntersectionPoints.value = \
            NodeFunctionUtil.execute_for_lists_with_block(calc_intersection_point,
                                                          build_ele.Object1,
                                                          build_ele.Object2,
                                                          list_squeeze = build_ele.IntersectionPoints.list_squeeze)
